==> zio-aws-glacier_2.13-5.17.151.2-sources.jar: zio/aws/glacier/model/ListMultipartUploadsRequest.scala <==
package zio.aws.glacier.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListMultipartUploadsRequest(
    accountId: String,
    vaultName: String,
    marker: Option[String] = None,
    limit: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest = {
    import ListMultipartUploadsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
      .builder()
      .accountId(accountId: java.lang.String)
      .vaultName(vaultName: java.lang.String)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(limit.map(value => value: java.lang.String))(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly =
    zio.aws.glacier.model.ListMultipartUploadsRequest.wrap(buildAwsValue())
}
object ListMultipartUploadsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.glacier.model.ListMultipartUploadsRequest =
      zio.aws.glacier.model.ListMultipartUploadsRequest(
        accountId,
        vaultName,
        marker.map(value => value),
        limit.map(value => value)
      )
    def accountId: String
    def vaultName: String
    def marker: Option[String]
    def limit: Option[String]
    def getAccountId: ZIO[Any, Nothing, String] = ZIO.succeed(accountId)
    def getVaultName: ZIO[Any, Nothing, String] = ZIO.succeed(vaultName)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getLimit: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ) extends zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly {
    override val accountId: String = impl.accountId(): String
    override val vaultName: String = impl.vaultName(): String
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val limit: Option[String] =
      scala.Option(impl.limit()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ): zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-glacier_2.13-5.19.31.3-sources.jar: zio/aws/glacier/model/ListMultipartUploadsRequest.scala <==
package zio.aws.glacier.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListMultipartUploadsRequest(
    accountId: String,
    vaultName: String,
    marker: Optional[String] = Optional.Absent,
    limit: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest = {
    import ListMultipartUploadsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
      .builder()
      .accountId(accountId: java.lang.String)
      .vaultName(vaultName: java.lang.String)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(limit.map(value => value: java.lang.String))(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly =
    zio.aws.glacier.model.ListMultipartUploadsRequest.wrap(buildAwsValue())
}
object ListMultipartUploadsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.glacier.model.ListMultipartUploadsRequest =
      zio.aws.glacier.model.ListMultipartUploadsRequest(
        accountId,
        vaultName,
        marker.map(value => value),
        limit.map(value => value)
      )
    def accountId: String
    def vaultName: String
    def marker: Optional[String]
    def limit: Optional[String]
    def getAccountId: ZIO[Any, Nothing, String] = ZIO.succeed(accountId)
    def getVaultName: ZIO[Any, Nothing, String] = ZIO.succeed(vaultName)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getLimit: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ) extends zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly {
    override val accountId: String = impl.accountId(): String
    override val vaultName: String = impl.vaultName(): String
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val limit: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.glacier.model.ListMultipartUploadsRequest
  ): zio.aws.glacier.model.ListMultipartUploadsRequest.ReadOnly = new Wrapper(
    impl
  )
}
